@@ -27,6 +27,8 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from glue.config import qt_client
+
 def setup():
     from edxia.glue.qt.loader import load_maps
     from edxia.glue.qt.points_loader import load_points
@@ -34,4 +36,8 @@ def setup():
     from edxia.glue.qt.bse_editor import bse_editor
     from edxia.glue.qt.subset_quantifier import subset_quantifier
     from edxia.glue.qt.exporter import numpy_mask_exporter,\
-        numpytxt_mask_exporter, image_mask_exporter
\ No newline at end of file
+        numpytxt_mask_exporter, image_mask_exporter
+    from edxia.glue.qt.phases import phases_loader, phases_editor
+    from edxia.glue.viewers.ratioplot.qt.data_viewer import RatioPlotViewer
+    qt_client.add(RatioPlotViewer)
+    from edxia.glue.viewers.ratioplot.toolbar_mode import FindPhaseCoord
