@@ -46,6 +46,11 @@ class SegmentedLabels(PartOfExperiment):
 
         self._nb_labels = labels.max()
 
+    @property
+    def composite(self):
+        """Return the composite image"""
+        return self._init_composite
+
     @property
     def nb_labels(self):
         """Return the number of labels."""
