@@ -30,12 +30,14 @@
 from glue.config import menubar_plugin
 from glue.core.component_link import ComponentLink
 from glue.core.component_id import ComponentID
+from glue.core.parse import ParsedCommand, ParsedComponentLink
 
 import qtpy.QtWidgets as qtw
 import qtpy.QtGui as qtg
 import qtpy.QtCore as qtc
 
 from edxia.utils.chemistry import molar_masses
+from edxia.utils.qt import set_busy_app
 
 components = list(molar_masses.keys())
 components.append("BSE")
@@ -45,36 +47,40 @@ def pts_ratios(numer, denom):
     return numer/denom
 
 @menubar_plugin("edxia: Link EDS components")
+@set_busy_app
 def component_linker(session, data_collection):
-    qtw.QApplication.setOverrideCursor(qtg.QCursor(qtc.Qt.WaitCursor))
-    try:
-        datas = data_collection.data
-        links = []
-        for ind, data in enumerate(datas):
-            for component in components:
-                cid = data.find_component_id(component)
-                if cid is not None:
-                    # Link to other components
-                    for ind2, data2 in enumerate(datas):
-                        if ind2 <= ind:
-                            continue
-                        cid2 = data2.find_component_id(component)
-                        if cid2 is not None:
-                            links.append(ComponentLink([cid,], cid2))
-                    # Ratio links
-                    if component in ["Al", "S", "Cl", "Mg", "Si", "Fe"]:
-                        cid_ca = data.find_component_id("Ca")
-                        if cid_ca is not None:
-                            ratio = ComponentID(component+"/Ca")
-                            link = ComponentLink([cid,cid_ca], ratio, using=pts_ratios)
+
+    datas = data_collection.data
+    links = []
+    for ind, data in enumerate(datas):
+        for component in components:
+            cid = data.find_component_id(component)
+            if cid is not None:
+                # Link to other components
+                for ind2, data2 in enumerate(datas):
+                    if ind2 <= ind:
+                        continue
+                    cid2 = data2.find_component_id(component)
+                    if cid2 is not None:
+                        links.append(ComponentLink([cid,], cid2))
+                if component in ["Al", "S", "Cl", "Mg", "Si", "Fe"]:
+                    cid_ca = data.find_component_id("Ca")
+                    if cid_ca is not None:
+                        # Define the ratios as ParsedCommand so they appear in the editor
+                        equation = "{"+component+"}/{Ca}"
+                        references = {"Ca": cid_ca, component: cid}
+                        cmd = ParsedCommand(equation, references)
+                        label = component+"/Ca"
+                        # only add if not already created
+                        if  data.find_component_id(label) is None:
+                            ratio = ComponentID(label)
+                            link = ParsedComponentLink(ratio, cmd)
                             link.compute(data)
-                            data.add_component_link(link)
-                            links.append(link)
+                            data.add_component_link(link) # this is sufficient
+                                                          # to add it to the
+                                                          # interface
 
-        data_collection.set_links(links)
-
-    finally:
-           qtw.QApplication.restoreOverrideCursor()
+    data_collection.set_links(links)
 
 
 
