@@ -44,31 +44,38 @@ from matplotlib.gridspec import GridSpec
 import qtpy.QtWidgets as qtw
 import qtpy.QtGui as qtg
 import qtpy.QtCore as qtc
+import qtpy.compat as qcompat
 
 from glue.config import importer
 from glue.utils.qt.helpers import load_ui
 from glue.core.coordinates import AffineCoordinates
 
+
 ## edxia import
 
 from ...core.experiment import MappingExperiment
 
 from edxia.filters import denoise
 
-from ...filters.denoise import DenoiseFilter, UniformFilter, GaussianFilter
-from ...io.loader import DefaultLoader, StackLoader
-from ...composite import CompositeChannels
-from ...composite.segmentation import SlicSegmenter
-from ...point_analysis.points import points_from_segmentation
+from edxia.filters.denoise import DenoiseFilter, UniformFilter, GaussianFilter, MedianFilter
+from edxia.io.loader import DefaultLoader, StackLoader
+from edxia.composite import CompositeChannels
+from edxia.composite.segmentation import SlicSegmenter
+from edxia.composite.color_analysis import ColorPCA
+from edxia.point_analysis.points import points_from_segmentation
+from edxia.core import Map
 
-from ...io.raw_io import TextMapFormat
-from ...io import raw_io
-from ...io.hdf5 import save_dataset, read_dataset
+from edxia.io.raw_io import TextMapFormat
+from edxia.io import raw_io
+from edxia.io.hdf5 import save_dataset, read_dataset
+
+from edxia.utils.qt import SetBusyApp
 
 from .. import gluedata_from_points, gluedata_from_stack_and_composite, gluedata_from_stack
 
 
-
+from skimage.filters.rank import median, maximum, minimum
+from skimage.morphology import disk
 
 
 
@@ -205,8 +212,9 @@ class LoadEDSdata(qtw.QDialog):
 
     def browse_for_pattern(self):
         """Browse the filesystem to find a BSE map and transform as pattern."""
-        full_bse_path, _ = qtw.QFileDialog.getOpenFileName(None, "Open map", ".","txt files (*.txt *.csv);;All Files (*)")
-
+        full_bse_path, _ = qcompat.getopenfilename(self,
+                                                   caption="Open BSE map",
+                                                   filters="txt files (*.txt *.csv);;All Files (*)")
         try:
             head, tail = full_bse_path.rsplit("BSE", maxsplit=1)
         except ValueError as e:
@@ -230,7 +238,8 @@ class LoadEDSdata(qtw.QDialog):
         self._ui.pattern_box.editingFinished.emit()
 
     def browse_for_dataset(self):
-        ds_path, _ = qtw.QFileDialog.getSaveFileName(None, "Save dataset", ".","hdf5 files (*.hdf5);;All Files (*)")
+        ds_path, _ = qcompat.getsavefilename(self, caption="Save dataset",
+                                             filters="hdf5 files (*.hdf5);;All Files (*)")
 
         if ds_path != "":
             self._ui.dataset_box.setText(ds_path)
@@ -315,10 +324,12 @@ class LoadEDSdata(qtw.QDialog):
                 ui.no_filter_check,
                 ui.tv_filter_check,
                 ui.mean_filter_check,
+                ui.median_filter_check,
                 ui.gaussian_filter_check,
 
                 ui.weight_filter_box,
                 ui.radius_filter_box,
+                ui.radius_filter_box_2,
                 ui.sigma_filter_box,
 
                 ui.test_filter_button,
@@ -372,6 +383,10 @@ class LoadEDSdata(qtw.QDialog):
             radius = self._ui.radius_filter_box.value()
             name = "UniformFilter({0})".format(radius)
             filters = [UniformFilter(radius),]
+        elif self._ui.median_filter_check.isChecked():
+            radius = self._ui.radius_filter_box_2.value()
+            name = "MedianFilter({0})".format(radius)
+            filters = [MedianFilter(radius),]
         elif self._ui.gaussian_filter_check.isChecked():
             sigma = self._ui.sigma_filter_box.value()
             name = "GaussianFilter({0})".format(sigma)
@@ -509,6 +524,9 @@ class LoadEDSdata(qtw.QDialog):
         coords = self.get_scale()
 
         extras = {}
+
+
+
         stack_has_changed = False
         if self.is_mass_input():
             if ui.unit_wt_button.isChecked() and ui.sox_box.isChecked():
@@ -525,24 +543,43 @@ class LoadEDSdata(qtw.QDialog):
         if stack_has_changed:
             loader = StackLoader(stack)
 
-        if ui.segmentation_check.isChecked():
-            channels = self.get_channels()
-            composite = loader.load_composite(channels)
 
+        if ui.segmentation_check.isChecked():
 
             bse_map =  loader.load_edsmap("BSE")
+            compactness = float(ui.compactness_box.text())
+            numberpts = float(ui.numberpts_box.text())
+            segmenter = SlicSegmenter(compactness, numberpts)
+
+            channels = self.get_channels()
+            composite = loader.load_composite(channels)
 
             if ui.bsemix_check.isChecked():
                 composite.mix_with_bse(bse_map, ui.alpha_box.value())
             if ui.filterbse_check.isChecked():
                 composite.map[bse_map.map<0.2,:] = 0
 
-            stack_data = gluedata_from_stack_and_composite(exp.label+"maps", stack, composite, coords=coords, extras=extras)
 
-            # segmentation
-            compactness = float(ui.compactness_box.text())
-            numberpts = float(ui.numberpts_box.text())
-            labels = SlicSegmenter(compactness, numberpts).apply(composite)
+            if ui.compositesegm_button.isChecked():
+
+                # segmentation
+                labels = segmenter.apply(composite)
+
+                pca = ColorPCA(labels)
+                pca_transformed = pca.transform_rgb(composite.map)
+                extras["PCA1"] = pca_transformed[:,:,0]
+                extras["PCA2"] = pca_transformed[:,:,1]
+                extras["PCA3"] = pca_transformed[:,:,2]
+
+            elif ui.bsesegm_button.isChecked():
+                radius = ui.bsesegm_radius_box.value()
+                image = median(bse_map.map, disk(radius))
+                image = minimum(maximum(image, disk(radius)), disk(radius))
+                bse_filter = Map("BSE", image, exp)
+                labels = segmenter.apply(bse_filter)
+
+            # stack and pts data
+            stack_data = gluedata_from_stack_and_composite(exp.label+"maps", stack, composite, coords=coords, extras=extras)
             pts = points_from_segmentation(stack, labels, mask_img=composite.map, include_yx=True, extras=extras)
             pts_data = gluedata_from_points(exp.label+"points", pts)
 
@@ -584,22 +621,23 @@ def load_maps():
 @importer("edxia: Import EDS/BSE maps (dataset)")
 def load_dataset():
     """Load maps in glue"""
-    full_dset_path, _ = qtw.QFileDialog.getOpenFileName(None, "Open dataset", ".","hdf5 files (*.hdf5 *.h5);;All Files (*)")
-
+    full_dset_path, _ = qcompat.getopenfilename(None, caption="Open dataset",
+                                                filters="hdf5 files (*.hdf5 *.h5);;All Files (*)")
     results = []
 
     if full_dset_path == "":
         return results
 
-    stack, composite, points, extras = read_dataset(full_dset_path)
-    exp = stack.parent
-    if composite is None:
-        results.append(gluedata_from_stack(exp.label+"maps", stack, extras=extras))
-    else:
-        results.append(gluedata_from_stack_and_composite(exp.label+"maps", stack, composite, extras=extras)) #, coords)
+    with SetBusyApp():
+        stack, composite, points, extras = read_dataset(full_dset_path)
+        exp = stack.parent
+        if composite is None:
+            results.append(gluedata_from_stack(exp.label+"maps", stack, extras=extras))
+        else:
+            results.append(gluedata_from_stack_and_composite(exp.label+"maps", stack, composite, extras=extras)) #, coords)
 
-    if points is not None:
-        results.append(gluedata_from_points(exp.label+"points", points))
+        if points is not None:
+            results.append(gluedata_from_points(exp.label+"points", points))
 
     return results
 
