@@ -28,6 +28,9 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import numpy as np
+import pandas as pd
+
+import configparser
 
 # some molar masses (g/mol)
 molar_masses = {
@@ -144,6 +147,7 @@ def normalize_composition(comp):
     tsum = sum(comp.values())
     for key, value in comp.items():
         comp[key] = value/tsum
+    return comp
 
 
 def mass_of_oxide_from_composition(comp):
@@ -164,4 +168,86 @@ def mass_of_oxide_from_mass_composition(comp):
 
 def relative_mass_of_oxide_from_mass_composition(comp):
     """Compute the relative mass of oxide from mass composition."""
-    return mass_of_oxide_from_mass_composition(comp)/sum(comp.values())
\ No newline at end of file
+    return mass_of_oxide_from_mass_composition(comp)/sum(comp.values())
+
+class PhaseDictionnary:
+    def __init__(self):
+        self._dict = {}
+        self._dict_compo = {}
+        self._nb_items = None
+
+    def __setitem__(self, name, formula):
+        """Add or update a phase"""
+        compo = formula_to_composition(formula)
+        self._dict[name] = formula
+        self._dict_compo[name] = normalize_composition(compo)
+
+    def __getitem__(self, name):
+        """Return a phase"""
+        return self._dict[name]
+
+    def __delitem(self, name):
+        """Delete or add a phase"""
+        del self._dict[name]
+        del self._dict_compo[name]
+
+    def __len__(self):
+        """Return the number of phases."""
+        return len(self._dict)
+
+    @property
+    def size(self):
+        """Return the maximum number of phases.
+
+        Returns None if no maximum set"""
+        return self._nb_items
+
+    @size.setter
+    def size(self, value):
+        """Set the maximum number of phases.
+
+        Returnrs None if no maximum set."""
+        self._nb_items = value
+
+    def composition(self, name):
+        """Return the composition of the dictionary. """
+        return self._dict_compo[name]
+
+    def elements(self, cache=False):
+        """Return all the elements"""
+        elements = set()
+        for compo in self._dict_compo.values():
+            elements.update(compo.keys())
+        return elements
+
+    def to_pandas(self):
+        """Return the dictionnary as a pandas dataframe"""
+        elements = self.elements()
+        if self.size is None:
+            nb_items = len(self)
+            indexes = self._dict.keys()
+        else:
+            nb_items = self.size
+            indexes = ["",]*nb_items
+            indexes[:len(self)] = self._dict.keys()
+
+        df = pd.DataFrame(data=np.zeros((nb_items,len(elements))),
+                          columns=elements, index=indexes)
+        for phase in self._dict.keys():
+            compo = self._dict_compo[phase]
+            for el, value in compo.items():
+                df.loc[phase][el]=value
+
+        return df
+
+    def from_config(self, filepath):
+        config = configparser.ConfigParser()
+        config.read(filepath)
+        self.size = int(config["Config"]["nb_phases"])
+        for phase, formula in config["Phases"].items():
+            self.__setitem__(phase, formula)
+
+def phases_df_from_file(file):
+    phases = PhaseDictionnary()
+    phases.from_config(file)
+    return phases.to_pandas()
\ No newline at end of file
